@@ -28,20 +28,23 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define RFutils_public_H 1
 
 #include <R_ext/Rdynload.h>
-#include "utils.h"
+#include "General_utils.h"
 
 
 
 
 extern "C" {
-  void R_init_RandomFieldsUtils(DllInfo VARIABLE_IS_NOT_USED *info);
-  void R_unload_RandomFieldsUtils(DllInfo VARIABLE_IS_NOT_USED *info);
+  void R_init_RandomFieldsUtils(DllInfo *info);
+  void R_unload_RandomFieldsUtils(DllInfo *info);
 
   SEXP struve(SEXP X, SEXP Nu, SEXP Factor_Sign, SEXP Expscaled);
   SEXP I0ML0(SEXP X);
-  SEXP solvePosDef(SEXP M, SEXP rhs, SEXP logdet);
+  SEXP SolvePosDef(SEXP M, SEXP rhs, SEXP logdet);
+  SEXP CholPosDef(SEXP M);
 
-  void R_init_RFutils(DllInfo *info);
+  SEXP RFoptions(SEXP options);
+  void RelaxUnknownRFoption(int *relax);
 }
 
-#endif
+#endif 
+ 
